'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = _interopDefault(require('prop-types'));

var cs = { "root": "index_root__2ePnr", "content": "index_content__2mU-3" };

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var Blurable = function (_React$Component) {
  inherits(Blurable, _React$Component);

  function Blurable(props) {
    classCallCheck(this, Blurable);

    var _this = possibleConstructorReturn(this, (Blurable.__proto__ || Object.getPrototypeOf(Blurable)).call(this, props));

    _this.clickHandler = _this.clickHandler.bind(_this);
    return _this;
  }

  createClass(Blurable, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      window.addEventListener('click', this.clickHandler);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('click', this.clickHandler);
    }
  }, {
    key: 'getRef',
    value: function getRef(ref) {
      this.ref = ref;
    }
  }, {
    key: 'getContentRef',
    value: function getContentRef(contentRef) {
      this.contentRef = contentRef;
    }
  }, {
    key: 'clickHandler',
    value: function clickHandler(evt) {
      var _props = this.props,
          onToggle = _props.onToggle,
          isOpen = _props.isOpen,
          closeOnContentClick = _props.closeOnContentClick;

      // needs to be opened
      // ref contains target and !this.props.isOpen

      if (this.ref.contains(evt.target) && !isOpen) {
        onToggle();
        return;
      }

      if (this.props.isOpen) {
        if (!closeOnContentClick && this.contentRef.contains(evt.target)) {
          return;
        }

        // needs to be closed
        this.props.onToggle();
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var style = {
        display: this.props.isOpen ? 'block' : 'none',
        transform: 'translateY(' + this.props.top + 'px)'
      };

      return React__default.createElement(
        'div',
        { className: cs.root, ref: this.getRef.bind(this) },
        this.props.children,
        React__default.createElement(
          'div',
          { style: style, className: cs.content, ref: this.getContentRef.bind(this) },
          this.props.content
        )
      );
    }
  }]);
  return Blurable;
}(React__default.Component);

Blurable.propTypes = {
  children: PropTypes.node.isRequired,
  content: PropTypes.node.isRequired,
  isOpen: PropTypes.bool.isRequired,
  onToggle: PropTypes.func.isRequired,
  top: PropTypes.number,
  closeOnContentClick: PropTypes.bool
};

Blurable.defaultProps = {
  top: 5,
  closeOnContentClick: false
};

var cs$1 = { "root": "index_root__3iZ50", "content": "index_content__2dzv3", "default": "index_default___OJV-", "white": "index_white__HTnch", "transparent": "index_transparent__1xIpS", "facebook": "index_facebook__1l07o", "submitting": "index_submitting__2hvqN" };

var Button = function Button(props) {
  var style = {
    width: props.fullWidth ? '100%' : 150
  };

  var onClick = function onClick(event) {
    if (!props.submitting) {
      props.onClick(event);
    }
  };

  var submittingClass = props.submitting ? cs$1.submitting : '';

  return React__default.createElement(
    'button',
    {
      className: cs$1.root + ' ' + cs$1[props.type] + ' ' + submittingClass,
      style: style,
      onClick: onClick,
      type: props.formType
    },
    React__default.createElement(
      'div',
      { className: cs$1.content },
      props.children
    )
  );
};

Button.propTypes = {
  children: PropTypes.node.isRequired,
  fullWidth: PropTypes.bool,
  onClick: PropTypes.func,
  type: PropTypes.oneOf(['default', 'white', 'transparent', 'facebook']),
  formType: PropTypes.oneOf(['button', 'submit']),
  submitting: PropTypes.bool
};

Button.defaultProps = {
  fullWidth: false,
  onClick: function onClick() {
    return false;
  },
  type: 'default',
  formType: 'button',
  submitting: false
};

var cs$2 = { "root": "index_root__3TOoP", "checkmark": "index_checkmark__2TyMg", "checked": "index_checked__3SlXw" };

var CheckBox = function CheckBox(props) {
  var className = cs$2.root + ' ' + (props.isChecked ? cs$2.checked : '');

  return React__default.createElement(
    'div',
    {
      className: className,
      onClick: props.onChange,
      role: 'checkbox',
      'aria-checked': props.isChecked,
      tabIndex: 0
    },
    React__default.createElement('div', { className: cs$2.checkmark })
  );
};

CheckBox.propTypes = {
  isChecked: PropTypes.bool.isRequired,
  onChange: PropTypes.func.isRequired
};

/**
 * Calculates flex basis based on 12 item grid
 * @param size
 */
var calculateSize = function calculateSize(size) {
  return 100 / 12 * size + '%';
};

/**
 * Detect configuration based on view port size
 * and given config
 * @param width Window width
 * @param config configuration object
 * @returns {*}
 */
var getViewPortConfig = function getViewPortConfig(width, config) {
  var sizes = [{
    name: 'xl',
    isDetected: width >= 1200,
    value: config.xl || false
  }, {
    name: 'lg',
    isDetected: width >= 992,
    value: config.lg || false
  }, {
    name: 'md',
    isDetected: width >= 768,
    value: config.md || false
  }, {
    name: 'sm',
    isDetected: width >= 576,
    value: config.sm || false
  }, {
    name: 'xs',
    isDetected: width >= 0,
    value: config.xs || false
  }];

  for (var i = 0; i < sizes.length; i += 1) {
    var size = sizes[i];
    // we detected screen size
    if (size.isDetected && size.value) {
      return size.value;
    }
  }

  return false;
};

/**
 * Return flex row styles based on config
 * Available styles
 * - align:
 * - justify:
 * - wrap:
 * - height
 * @param config
 * @returns {{}}
 */
var getRowStyles = function getRowStyles(config) {
  return {
    alignItems: config.align || 'stretch',
    justifyContent: config.justify || 'flex-start',
    flexWrap: config.wrap || false,
    height: config.height || 'auto'
  };
};

/**
 * Return flex column styles based on config
 * When given integer calculates flex-basis
 * Available styles
 * - size:
 * - offset:
 * - left:
 * - right:
 * - top:
 * - bottom:
 * @param config
 * @returns {{}}
 */
var getColumnStyles = function getColumnStyles(config) {
  if (typeof config === 'number') {
    return {
      flexBasis: calculateSize(config)
    };
  }

  return {
    flexBasis: config.size ? calculateSize(config.size) : 'auto',
    marginLeft: config.offset ? calculateSize(config.offset) : 0
  };
};

var Col = function (_React$Component) {
  inherits(Col, _React$Component);

  function Col(props) {
    classCallCheck(this, Col);

    var _this = possibleConstructorReturn(this, (Col.__proto__ || Object.getPrototypeOf(Col)).call(this, props));

    _this.state = {
      style: {},
      viewPortConfig: {}
    };

    _this.resize = _this.resize.bind(_this);
    return _this;
  }

  createClass(Col, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      window.addEventListener('resize', this.resize);

      // Initial resize call
      this.resize();
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('resize', this.resize);
    }
  }, {
    key: 'resize',
    value: function resize() {
      var _props = this.props,
          xl = _props.xl,
          lg = _props.lg,
          md = _props.md,
          sm = _props.sm,
          xs = _props.xs;


      if (!xl && !lg && !md && !sm && !xs) {
        return;
      }

      var viewPortConfig = getViewPortConfig(window.innerWidth, {
        xl: xl, lg: lg, md: md, sm: sm, xs: xs
      });

      this.setState({
        viewPortConfig: viewPortConfig,
        style: getColumnStyles(viewPortConfig)
      });
    }
  }, {
    key: 'render',
    value: function render() {
      var wrapperStyle = {
        paddingLeft: this.state.viewPortConfig.left || 0,
        paddingRight: this.state.viewPortConfig.right || 0,
        paddingTop: this.state.viewPortConfig.top || 0,
        paddingBottom: this.state.viewPortConfig.bottom || 0
      };

      return React__default.createElement(
        'div',
        { style: this.state.style },
        React__default.createElement(
          'div',
          { style: wrapperStyle },
          this.props.children
        )
      );
    }
  }]);
  return Col;
}(React__default.Component);

var shape = PropTypes.oneOfType([PropTypes.number, PropTypes.shape({
  size: PropTypes.number,
  offset: PropTypes.number,
  top: PropTypes.number,
  left: PropTypes.number,
  right: PropTypes.number,
  bottom: PropTypes.number
})]);

Col.propTypes = {
  xl: shape,
  lg: shape,
  md: shape,
  sm: shape,
  xs: shape,
  children: PropTypes.node.isRequired
};

Col.defaultProps = {
  xl: null,
  lg: null,
  md: null,
  sm: null,
  xs: null
};

var cs$3 = { "root": "index_root__15gCa", "active": "index_active__3WeaN" };

var DropDownItem = function DropDownItem(props) {
  var onClick = function onClick(event) {
    props.onClick(props.item, event);
  };

  var className = cs$3.root + ' ' + (props.isActive ? cs$3.active : '');

  return React__default.createElement(
    'div',
    {
      role: 'presentation',
      onClick: onClick,
      className: className
    },
    props.item.label
  );
};

DropDownItem.propTypes = {
  item: PropTypes.shape({
    label: PropTypes.string.isRequired
  }).isRequired,
  isActive: PropTypes.bool.isRequired,
  onClick: PropTypes.func.isRequired
};

var cs$4 = { "root": "index_root__3P4iB" };

var Flex = function (_React$Component) {
  inherits(Flex, _React$Component);

  function Flex(props) {
    classCallCheck(this, Flex);

    var _this = possibleConstructorReturn(this, (Flex.__proto__ || Object.getPrototypeOf(Flex)).call(this, props));

    _this.state = {
      style: {}
    };

    _this.resize = _this.resize.bind(_this);
    return _this;
  }

  createClass(Flex, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      window.addEventListener('resize', this.resize);

      // Initial resize call
      this.resize();
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('resize', this.resize);
    }
  }, {
    key: 'resize',
    value: function resize() {
      var viewPortConfig = getViewPortConfig(window.innerWidth, {
        xl: this.props.xl,
        lg: this.props.lg,
        md: this.props.md,
        sm: this.props.sm,
        xs: this.props.xs
      });

      this.setState({
        style: getRowStyles(viewPortConfig)
      });
    }
  }, {
    key: 'render',
    value: function render() {
      return React__default.createElement(
        'div',
        { className: cs$4.root, style: this.state.style },
        this.props.children
      );
    }
  }]);
  return Flex;
}(React__default.Component);

var shape$1 = PropTypes.shape({
  align: PropTypes.string,
  justify: PropTypes.string,
  wrap: PropTypes.string,
  height: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
});

Flex.propTypes = {
  xl: shape$1,
  lg: shape$1,
  md: shape$1,
  sm: shape$1,
  xs: shape$1,
  children: PropTypes.node.isRequired
};

Flex.defaultProps = {
  xl: null,
  lg: null,
  md: null,
  sm: null,
  xs: null
};

var cs$5 = { "root": "index_root__2PixZ" };

var Text = function Text(props) {
  var style = {
    color: props.color,
    textTransform: props.transform,
    fontSize: props.fontSize,
    fontWeight: props.fontWeight,
    lineHeight: props.lineHeight
  };

  return React__default.createElement(
    'div',
    { style: style, className: cs$5.root },
    props.children
  );
};

Text.propTypes = {
  children: PropTypes.node.isRequired,
  color: PropTypes.string,
  fontSize: PropTypes.number,
  transform: PropTypes.oneOf(['uppercase', 'capitalize', 'lowercase', 'none']),
  fontWeight: PropTypes.string,
  lineHeight: PropTypes.string
};

Text.defaultProps = {
  color: '#2a2a2a',
  transform: 'none',
  fontSize: 16,
  fontWeight: 'normal',
  lineHeight: 'normal'
};

var cs$6 = { "root": "index_root__ev7Oi", "content": "index_content__j1OsY", "downArrow": "index_downArrow__17xXz" };

var DropDownMenu = function (_React$Component) {
  inherits(DropDownMenu, _React$Component);

  function DropDownMenu(props) {
    classCallCheck(this, DropDownMenu);

    var _this = possibleConstructorReturn(this, (DropDownMenu.__proto__ || Object.getPrototypeOf(DropDownMenu)).call(this, props));

    _this.state = {
      isOpen: false
    };

    _this.onToggle = _this.onToggle.bind(_this);
    return _this;
  }

  createClass(DropDownMenu, [{
    key: 'onToggle',
    value: function onToggle() {
      this.setState({
        isOpen: !this.state.isOpen
      });
    }
  }, {
    key: 'onChange',
    value: function onChange(item) {
      this.props.onChange(item);
    }
  }, {
    key: 'renderItems',
    value: function renderItems() {
      var _this2 = this;

      var map = function map(item, index) {
        return React__default.createElement(DropDownItem, {
          key: index,
          item: item,
          onClick: _this2.onChange.bind(_this2),
          isActive: item.label === _this2.props.active.label
        });
      };

      return this.props.items.map(map);
    }
  }, {
    key: 'renderContent',
    value: function renderContent() {
      return React__default.createElement(
        'div',
        { className: cs$6.content },
        this.renderItems()
      );
    }
  }, {
    key: 'render',
    value: function render() {
      var color = this.state.isOpen ? '#7588ff' : '#2a2a2a';

      return React__default.createElement(
        Blurable,
        {
          content: this.renderContent(),
          isOpen: this.state.isOpen,
          onToggle: this.onToggle,
          top: 10,
          closeOnContentClick: true
        },
        React__default.createElement(
          'div',
          { className: cs$6.root },
          React__default.createElement(
            Flex,
            { xs: { align: 'center' } },
            React__default.createElement(
              Col,
              null,
              React__default.createElement(
                Text,
                { fontSize: 18, color: color },
                this.props.placeholder,
                ':'
              )
            ),
            React__default.createElement(
              Col,
              { xs: { left: 3 } },
              React__default.createElement(
                Text,
                {
                  fontSize: 18,
                  color: color
                },
                this.props.active.label
              )
            ),
            React__default.createElement(
              Col,
              { xs: { left: 12 } },
              React__default.createElement('i', { className: cs$6.downArrow })
            )
          )
        )
      );
    }
  }]);
  return DropDownMenu;
}(React__default.Component);

DropDownMenu.propTypes = {
  placeholder: PropTypes.string.isRequired,
  items: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.string.isRequired
  })).isRequired,
  active: PropTypes.shape({
    label: PropTypes.string.isRequired
  }).isRequired,
  onChange: PropTypes.func.isRequired
};

var cs$7 = { "label": "index_label__3nqPc", "error": "index_error__15fPc", "root": "index_root__3GiOI" };

var FormGroup = function FormGroup(props) {
  var className = (props.errorText !== '' ? cs$7.error : '') + ' ' + cs$7.label;

  return React__default.createElement(
    'div',
    { className: cs$7.root },
    React__default.createElement(
      'div',
      { className: className },
      props.errorText !== '' ? props.errorText : props.label
    ),
    React__default.createElement(
      'div',
      null,
      props.children
    )
  );
};

FormGroup.propTypes = {
  label: PropTypes.string.isRequired,
  children: PropTypes.node.isRequired,
  errorText: PropTypes.string
};

FormGroup.defaultProps = {
  errorText: ''
};

var cs$8 = { "root": "index_root__3gOND" };

var Heading = function Heading(props) {
  var style = {
    color: props.color,
    textTransform: props.transform,
    fontWeight: props.fontWeight,
    lineHeight: props.lineHeight,
    fontSize: 26
  };

  return React__default.createElement(
    'h1',
    { style: style, className: cs$8.root },
    props.children
  );
};

Heading.propTypes = {
  children: PropTypes.node.isRequired,
  color: PropTypes.string,
  transform: PropTypes.oneOf(['uppercase', 'capitalize', 'lowercase', 'none']),
  fontWeight: PropTypes.string,
  lineHeight: PropTypes.string
};

Heading.defaultProps = {
  color: '#2a2a2a',
  transform: 'none',
  fontWeight: 'normal',
  lineHeight: 'normal'
};

var Image = function Image(props) {
  var style = {
    width: props.width
  };

  if (props.type === 'rounded') {
    style.borderRadius = '20%';
  } else if (props.type === 'circle') {
    style.borderRadius = '50%';
  }

  return React__default.createElement('img', { style: style, src: props.src, alt: props.alt });
};

Image.propTypes = {
  src: PropTypes.string.isRequired,
  alt: PropTypes.string.isRequired,
  width: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired,
  type: PropTypes.oneOf(['rounded', 'circle', ''])
};

Image.defaultProps = {
  type: ''
};

var cs$9 = { "root": "index_root__2z0DX", "error": "index_error__1_nap", "fullBordered": "index_fullBordered__tFHAe", "bottomBordered": "index_bottomBordered__3PPIC" };

var Input = function Input(props) {
  var borderClassName = props.bordered ? cs$9.fullBordered : cs$9.bottomBordered;
  var errorClass = props.hasError ? cs$9.error : '';

  return React__default.createElement('input', {
    className: cs$9.root + ' ' + borderClassName + ' ' + errorClass,
    value: props.value,
    placeholder: props.placeholder,
    onChange: props.onChange,
    type: props.type,
    readOnly: props.readonly
  });
};

Input.propTypes = {
  value: PropTypes.string.isRequired,
  type: PropTypes.string,
  placeholder: PropTypes.string,
  onChange: PropTypes.func,
  bordered: PropTypes.bool,
  readonly: PropTypes.bool,
  hasError: PropTypes.bool
};

Input.defaultProps = {
  placeholder: '',
  bordered: true,
  type: 'text',
  onChange: function onChange() {
    return false;
  },
  readonly: false,
  hasError: false
};

var Padding = function Padding(props) {
  var padding = props.padding;

  var style = void 0;

  if (typeof padding === 'number') {
    style = { padding: padding };
  } else {
    style = {
      paddingTop: props.padding.top || 0,
      paddingRight: props.padding.right || 0,
      paddingBottom: props.padding.bottom || 0,
      paddingLeft: props.padding.left || 0
    };
  }

  return React__default.createElement(
    'div',
    { style: style },
    props.children
  );
};

Padding.propTypes = {
  children: PropTypes.node.isRequired,
  padding: PropTypes.oneOfType([PropTypes.shape({
    top: PropTypes.number,
    left: PropTypes.number,
    right: PropTypes.number,
    bottom: PropTypes.number
  }), PropTypes.number]).isRequired
};

var cs$10 = { "root": "index_root__1Sk5O" };

var Panel = function Panel(props) {
  return React__default.createElement(
    'div',
    { className: cs$10.root },
    props.children
  );
};

Panel.propTypes = {
  children: PropTypes.node.isRequired
};

var Content = function Content(props) {
  var style = {
    backgroundColor: 'white',
    boxSizing: 'border-box'
  };

  if (props.isPadded) {
    style.padding = '20px 30px';
  }

  return React__default.createElement(
    'div',
    { style: style },
    props.children
  );
};

Content.propTypes = {
  children: PropTypes.node.isRequired,
  isPadded: PropTypes.bool
};

Content.defaultProps = {
  isPadded: true
};

var cs$11 = { "root": "index_root__24Ld8" };

var Header = function Header(props) {
  return React__default.createElement(
    'div',
    { className: cs$11.root },
    props.children
  );
};

Header.propTypes = {
  children: PropTypes.node.isRequired
};

var cs$12 = { "slideItem": "index_slideItem__2rWxT", "checkBox": "index_checkBox__2DAYO", "active": "index_active__3Uu21" };

var Item = function Item(props) {
  var className = props.isSelected ? cs$12.active : '';
  var onToggle = function onToggle() {
    props.onToggle(props.item);
  };

  return React__default.createElement(
    'div',
    { role: 'presentation', onClick: onToggle, className: cs$12.slideItem + ' ' + className },
    React__default.createElement(
      'div',
      { className: cs$12.checkBox },
      React__default.createElement(CheckBox, { isChecked: props.isSelected, onChange: function onChange() {
          return false;
        } })
    ),
    React__default.createElement('img', { src: props.item, alt: 'Slide item' })
  );
};

Item.propTypes = {
  onToggle: PropTypes.func.isRequired,
  item: PropTypes.string.isRequired,
  isSelected: PropTypes.bool.isRequired
};

var PhotoSelector = function (_Component) {
  inherits(PhotoSelector, _Component);

  function PhotoSelector() {
    classCallCheck(this, PhotoSelector);
    return possibleConstructorReturn(this, (PhotoSelector.__proto__ || Object.getPrototypeOf(PhotoSelector)).apply(this, arguments));
  }

  createClass(PhotoSelector, [{
    key: 'renderItems',
    value: function renderItems() {
      var _this2 = this;

      var map = function map(item, index) {
        var isSelected = _this2.props.selected.indexOf(item) !== -1;
        return React__default.createElement(
          Col,
          { key: index, xs: { right: 15, top: 15 } },
          React__default.createElement(Item, { item: item, isSelected: isSelected, onToggle: _this2.props.onToggle })
        );
      };

      return this.props.photos.map(map);
    }
  }, {
    key: 'render',
    value: function render() {
      return React__default.createElement(
        'div',
        { className: cs$12.root },
        React__default.createElement(
          'div',
          null,
          React__default.createElement(
            Flex,
            { xs: { wrap: 'wrap' } },
            this.renderItems()
          )
        )
      );
    }
  }]);
  return PhotoSelector;
}(React.Component);

PhotoSelector.propTypes = {
  photos: PropTypes.arrayOf(PropTypes.string).isRequired,
  selected: PropTypes.arrayOf(PropTypes.string).isRequired,
  onToggle: PropTypes.func.isRequired
};

var cs$13 = { "root": "index_root__2rv6I", "button": "index_button__2hL_r", "active": "index_active__2HQ7S" };

var _this = undefined;

var renderOptions = function renderOptions(options, value, onChange) {
  var map = function map(item, index) {
    var gridSize = 12 / options.length;
    var className = cs$13.button + ' ' + (value === item.value ? cs$13.active : '');

    return React__default.createElement(
      Col,
      { xs: gridSize, key: index },
      React__default.createElement(
        'div',
        {
          role: 'button',
          tabIndex: 0,
          onClick: onChange.bind(_this, item.value),
          className: className
        },
        item.label
      )
    );
  };

  return options.map(map);
};

var RadioButtonGroup = function RadioButtonGroup(props) {
  var onChange = function onChange(value) {
    props.onChange(value);
  };

  return React__default.createElement(
    'div',
    { className: cs$13.root },
    React__default.createElement(
      Flex,
      { xs: { align: 'center' } },
      renderOptions(props.options, props.value, onChange)
    )
  );
};

RadioButtonGroup.propTypes = {
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired
  })).isRequired,
  value: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired
};

exports.Blurable = Blurable;
exports.Button = Button;
exports.CheckBox = CheckBox;
exports.Col = Col;
exports.DropDownItem = DropDownItem;
exports.DropDownMenu = DropDownMenu;
exports.Flex = Flex;
exports.FormGroup = FormGroup;
exports.Heading = Heading;
exports.Image = Image;
exports.Input = Input;
exports.Padding = Padding;
exports.Panel = Panel;
exports.PanelContent = Content;
exports.PanelHeader = Header;
exports.PhotoSelector = PhotoSelector;
exports.RadioButtonGroup = RadioButtonGroup;
exports.Text = Text;
